@@ -27,4 +27,9 @@ where
     BadInputError(Utf8Error),
     WouldBlock,
     HistoryError,
-}
\ No newline at end of file
+}
+
+pub enum Input<'a> {
+    Control(u8),
+    Command((&'a str, &'a str)),
+}
